@@ -5,13 +5,12 @@ from .cpp.fast_geometry import (
     calc_dihedral_angles,
     calc_volume_grad,
 )
-from .signed_distance_functions import dblock, dintersect, drectangle
+from .signed_distance_functions import Rectangle, Cube, Circle, drectangle, dblock
 from .utils import (
-    SignedDistanceFunctionGenerator,
     calc_re_ratios,
     delete_boundary_entities,
-    doAnyOverlap,
-    fixmesh,
+    do_any_overlap,
+    fix_mesh,
     get_boundary_edges,
     get_boundary_entities,
     get_boundary_facets,
@@ -23,33 +22,35 @@ from .utils import (
     laplacian2,
     linter,
     remove_external_entities,
-    simpqual,
-    simpvol,
+    simp_qual,
+    simp_vol,
     unique_rows,
     vertex_to_entities,
-    vtInEntity3,
+    vertex_in_entity3,
 )
 
 __all__ = [
-    "SignedDistanceFunctionGenerator",
     "calc_re_ratios",
     "calc_volume_grad",
     "calc_circumsphere_grad",
     "calc_3x3determinant",
     "calc_4x4determinant",
-    "dblock",
+    "Rectangle",
+    "Cube",
+    "Circle",
     "drectangle",
+    "dblock",
     "dintersect",
     "calc_dihedral_angles",
-    "doAnyOverlap",
+    "do_any_overlap",
     "linter",
     "laplacian2",
     "vertex_to_entities",
     "remove_external_entities",
     "unique_rows",
-    "fixmesh",
-    "simpvol",
-    "simpqual",
+    "fix_mesh",
+    "simp_vol",
+    "simp_qual",
     "get_centroids",
     "get_edges",
     "get_facets",
@@ -59,5 +60,5 @@ __all__ = [
     "get_boundary_edges",
     "get_boundary_facets",
     "get_winded_boundary_edges",
-    "vtInEntity3",
+    "vertex_in_entity3",
 ]
