@@ -1,10 +1,5 @@
 import numpy as np
-import scipy as sp
-import scipy.ndimage
 import scipy.sparse as spsparse
-import skfmm
-from mpi4py import MPI
-from scipy.interpolate import RegularGridInterpolator
 
 from ..generation.cpp import c_cgal
 from . import signed_distance_functions as sdf
@@ -14,177 +9,44 @@ from .cpp import fast_geometry as gutils
 dete = gutils.calc_4x4determinant
 
 
-class SignedDistanceFunctionGenerator:
-    """Tool used to build signed distance functions
-    from seismic velocity models.
-    """
-
-    def __init__(  # noqa: ignore=C901
-        self,
-        field=None,
-        min_threshold=1487,
-        max_threshold=99999.0,
-        bbox=None,
-        gridspacing=None,
-        method="union",
-        narrow=0.0,
-        comm=None,
-        flip=False,
-    ):
-        """Class constructor for :class:`SignedDistanceFunctionGenerator`
-
-        :param field: seismic velocity model on a structured grid
-        :type field: array-like with dimensions (nz, nx) or (nz, nx, ny)
-        :param min_threshold: seismic velocity min threshold (default=1487 m/s) for which all values > threshold will be meshed
-        :type min_threshold: float, optional
-        :param max_threshold: seismic velocity max. threshold (default=99999 m/s) for which all values < threshold will be meshed
-        :param bbox: bounding box containing domain extents.
-        :type bbox: tuple with size (2*dim). For example, in 2D `(zmin, zmax, xmin, xmax)`
-        :param gridspacing: space between points of seismic velocity model in meters, required
-        :type gridspacing: tuple with size (dim)
-        :param method: method used to combine subsection with bounding box. Currently only the default==union.
-        :type method: string, optional
-        :param narrow: only calculate SDF within a region close to the isocontour default=0.0 i.e., calc'ed everywhere
-        :type narrow: float64, optional
-        :param comm: MPI4py communicator default==None
-        :type comm: MPI4py communicator object, optional
-        :param flip: Whether to flip the signed distance function or not (default=False)
-        :type flip: boolean
-
-        """
-        self.field = field
-        self.min_threshold = min_threshold
-        self.max_threshold = max_threshold
-        self.bbox = bbox
-        self.gridspacing = gridspacing
-        self.method = method
-        self.narrow_band = narrow
-        self.flip = flip
-        self.SDF = None
-
-        comm = comm or MPI.COMM_WORLD
-
-        if comm.rank == 0:
-            print("Building a signed distance function from data...", flush=True)
-
-            if field is None:
-                raise ValueError(
-                    "field must be specified as a grid of dim containing values to threshold (e.g., MeshSizeFunction object.vp)."
-                )
-
-            if bbox is None:
-                raise ValueError(
-                    "bbox must be a tuple of corner extents in z --> x (--> y) fashion"
-                )
-            dim = int(len(bbox) / 2)
-            if dim < 2 or dim > 3:
-                raise ValueError("dimension is invalid, is bbox specified correctly?")
-            if gridspacing is None or len(gridspacing) < (dim - 1):
-                raise ValueError("gridspacing must be larger than 0.")
-
-            if dim == 2:
-                nz, nx = self.field.shape
-            elif dim == 3:
-                nx, ny, nz = self.field.shape
-
-            phi = np.ones_like(self.field)
-            phi[
-                np.logical_and(
-                    self.field > self.min_threshold, self.field < self.max_threshold
-                )
-            ] = -1
-            # call fast marching method
-            d = skfmm.distance(phi, [*self.gridspacing], narrow=self.narrow_band)
-            if self.narrow_band > 0:
-                d[d > self.narrow_band] = self.narrow_band
-                d[d < -self.narrow_band] = -self.narrow_band
-
-            if self.flip:
-                print("Flipping the distance sign...", flush=True)
-                d *= -1
-
-            # create the grid vectors
-            if dim == 2:
-                zvec = np.linspace(self.bbox[0], self.bbox[1], nz)
-                xvec = np.linspace(self.bbox[2], self.bbox[3], nx)
-                z, x = np.meshgrid(zvec, xvec)
-                # Apply gaussian filter
-                sigma = [10, 10]
-                d = sp.ndimage.filters.gaussian_filter(d, sigma, mode="constant")
-                interpolant = RegularGridInterpolator(
-                    (zvec, xvec), d, bounds_error=False, fill_value=None
-                )
-            if dim == 3:
-                # Apply gaussian filter
-                sigma = [10, 10, 10]
-                d = sp.ndimage.filters.gaussian_filter(d, sigma, mode="constant")
-                zvec = np.linspace(self.bbox[0], self.bbox[1], nz)
-                xvec = np.linspace(self.bbox[2], self.bbox[3], nx)
-                yvec = np.linspace(self.bbox[4], self.bbox[5], ny)
-                x, y, z = np.meshgrid(xvec, yvec, zvec)
-                d = d.transpose((2, 0, 1))
-                interpolant = RegularGridInterpolator(
-                    (zvec, xvec, yvec), d, bounds_error=False, fill_value=None
-                )
-
-            # interpolant of level-set
-            def SDF1(p):
-                return interpolant(p)
-
-            # primary interpolant of box
-            if dim == 2:
-
-                def SDF2(p):
-                    return sdf.drectangle(p, *self.bbox)
-
-            elif dim == 3:
-
-                def SDF2(p):
-                    return sdf.dblock(p, *self.bbox)
-
-            # intersect with box
-            if method == "union":
-
-                def SDF(p):
-                    d = np.stack((SDF1(p), SDF2(p)), axis=-1)
-                    return np.amax(d, 1)
-
-                self.SDF = SDF
-
-            else:
-                raise NotImplementedError(
-                    "Other methods not yet supported besides union"
-                )
-
-
-def calc_re_ratios(vertices, entities):
+def calc_re_ratios(vertices, entities, dim=2):
     """Calculate radius edge ratios--mesh quality metric
 
     :param vertices: point coordinates of the mesh vertices'
-    :type vertices: numpy.ndarray[float64 x dim]
+    :type vertices: numpy.ndarray[`float` x dim]
     :param entities: mesh connectivity table
-    :type entities: numpy.ndarray[int x (dim + 1)]
+    :type entities: numpy.ndarray[`int` x (dim + 1)]
 
-    :return: dihedral angles: array of radius-to-edge ratios
-    :rtype: dihedral angles: numpy.ndarray[float64 x 1]
+    :return: ce_ratios: array of radius-to-edge ratios
+    :rtype: ce_ratios: numpy.ndarray[`float` x 1]
     """
     # circumradius/shortest edge length
-    bars = np.concatenate(
-        [
-            entities[:, [0, 1]],
-            entities[:, [1, 2]],
-            entities[:, [2, 0]],
-            entities[:, [0, 3]],
-            entities[:, [1, 3]],
-            entities[:, [2, 3]],
-        ]
-    )
-    barvec = vertices[bars[:, 0]] - vertices[bars[:, 1]]
-    L = np.sqrt((barvec ** 2).sum(1))
-    L = np.reshape(L, (6, len(entities)))
+    if dim == 2:
+        bars = np.concatenate(
+            [entities[:, [0, 1]], entities[:, [1, 2]], entities[:, [2, 0]]]
+        )
+    elif dim == 3:
+        bars = np.concatenate(
+            [
+                entities[:, [0, 1]],
+                entities[:, [1, 2]],
+                entities[:, [2, 0]],
+                entities[:, [0, 3]],
+                entities[:, [1, 3]],
+                entities[:, [2, 3]],
+            ]
+        )
+    else:
+        raise ValueError("Dimension invalid")
+    bar_vec = vertices[bars[:, 0]] - vertices[bars[:, 1]]
+    L = np.sqrt((bar_vec ** 2).sum(1))
+    L = np.reshape(L, (3 * (dim - 1), len(entities)))
     # min edge length i every tetra
     minL = np.amin(L, axis=0)
-    cc = c_cgal.circumballs3(vertices[entities.flatten()])
+    if dim == 2:
+        cc = c_cgal.circumballs2(vertices[entities.flatten()])
+    elif dim == 3:
+        cc = c_cgal.circumballs3(vertices[entities.flatten()])
     r = cc[:, -1]
     return np.sqrt(r) / minL
 
@@ -193,20 +55,20 @@ def remove_external_entities(vertices, entities, extent, dim=2):
     """Remove entities with all dim+1 vertices outside block.
 
     :param vertices: point coordinates of mesh
-    :type vertices: numpy.ndarray[float64 x dim]
+    :type vertices: numpy.ndarray[`float` x dim]
     :param entities: mesh connectivity
-    :type entities: numpy.ndarray[int x (dim + 1)]
+    :type entities: numpy.ndarray[`int` x (dim + 1)]
     :param extent: coords. of the local block extents
-    :type extent: numpy.ndarray[tuple(float64 x (2*dim))]
+    :type extent: numpy.ndarray[tuple(`float` x (2*dim))]
     :param dim: dimension of mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
     :return: vertices_new: point coordinates of mesh w/ removed entities
-    :rtype: numpy.ndarray[float64 x dim]
+    :rtype: numpy.ndarray[`float` x dim]
     :return: entities_new: mesh connectivity w/ removed entities
-    :rtype: numpy.ndarray[int x (dim +1)]
+    :rtype: numpy.ndarray[`int` x (dim +1)]
     :return: jx: mapping from old point indexing to new point indexing
-    :rtype: numpy.ndarray[int x 1]
+    :rtype: numpy.ndarray[`int` x 1]
     """
 
     if dim == 2:
@@ -229,7 +91,7 @@ def remove_external_entities(vertices, entities, extent, dim=2):
         )
     isOut = np.reshape(signed_distance > 0.0, (-1, (dim + 1)))
     entities_new = entities[(np.sum(isOut, axis=1) != (dim + 1))]
-    vertices_new, entities_new, jx = fixmesh(vertices, entities_new, dim=dim)
+    vertices_new, entities_new, jx = fix_mesh(vertices, entities_new, dim=dim)
     return vertices_new, entities_new, jx
 
 
@@ -237,18 +99,18 @@ def vertex_to_entities(vertices, entities, dim=2):
     """Determine which elements are connected to which vertices.
 
     :param vertices: point coordinates of mesh vertices
-    :type vertices: numpy.ndarray[float64 x dim]
+    :type vertices: numpy.ndarray[`float` x dim]
     :param entities: mesh connectivity
-    :type entities: numpy.ndarray[int x (dim + 1)]
+    :type entities: numpy.ndarray[`int` x (dim + 1)]
     :param dim: dimension of mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
     :return: vtoe: indices of entities connected to each vertex
-    :rtype: numpy.ndarray[int x 1]
+    :rtype: numpy.ndarray[`int` x 1]
 
     :return: vtoe_pointer: indices into `vtoe` such that vertex `v` is connected to
                           `vtoe[vtoe_pointer[v]:vtoe_pointer[v+1]]` entities
-    :rtype: numpy.ndarray[int x 1]
+    :rtype: numpy.ndarray[`int` x 1]
     """
     num_entities = len(entities)
 
@@ -273,18 +135,18 @@ def unique_rows(A, return_index=False, return_inverse=False):
     A = B[J,:] and B = A[I,:]
 
     :param  A: array of data
-    :type A: numpy.ndarray[int/float64 x N]
+    :type A: numpy.ndarray[`int`/`float` x N]
     :param return_index: whether to return the indices of unique data
-    :type return_index: bool, optional
+    :type return_index: `boolean`, optional
     :param return_inverse: whether to return the inverse mapping back to A from B.
-    :type return_inverse: bool, optional
+    :type return_inverse: `boolean`, optional
 
     :return: B: array of data with duplicates removed
-    :rtype: numpy.ndarray[int/float64 x N]
+    :rtype: numpy.ndarray[`int`/`float` x N]
     :return: I: array of indices to unique data B.
-    :rtype: numpy.ndarray[int x 1]
+    :rtype: numpy.ndarray[`int` x 1]
     :return: J: array of indices to A from B.
-    :rtype: numpy.ndarray[int x 1]
+    :rtype: numpy.ndarray[`int` x 1]
     """
     A = np.require(A, requirements="C")
     assert A.ndim == 2, "array must be 2-dim'l"
@@ -309,16 +171,16 @@ def unique_rows(A, return_index=False, return_inverse=False):
             return B
 
 
-def simpvol(p, t):
+def simp_vol(p, t):
     """Signed volumes of the simplex elements in the mesh.
 
     :param p: point coordinates of mesh
-    :type p: numpy.ndarray[float64 x dim]
+    :type p: numpy.ndarray[`float` x dim]
     :param t: mesh connectivity
-    :type t: numpy.ndarray[int x (dim + 1)]
+    :type t: numpy.ndarray[`int` x (dim + 1)]
 
     :return: volume: signed volume of entity/simplex.
-    :rtype: numpy.ndarray[float64 x 1]
+    :rtype: numpy.ndarray[`float` x 1]
     """
 
     dim = p.shape[1]
@@ -338,25 +200,25 @@ def simpvol(p, t):
         raise NotImplementedError
 
 
-def fixmesh(p, t, ptol=2e-13, dim=2, delunused=False):
+def fix_mesh(p, t, ptol=2e-13, dim=2, delete_unused=False):
     """Remove duplicated/unused vertices and entities and
        ensure orientation of entities is CCW.
 
     :param p: point coordinates of mesh
-    :type p: numpy.ndarray[float64 x dim]
+    :type p: numpy.ndarray[`float` x dim]
     :param t: mesh connectivity
-    :type t: numpy.ndarray[int x (dim + 1)]
+    :type t: numpy.ndarray[`int` x (dim + 1)]
     :param ptol: point tolerance to detect duplicates
-    :type ptol: float64, optional
+    :type ptol: `float`, optional
     :param dim: dimension of mesh
-    :type dim: int, optional
-    :param delunused: flag to delete disjoint vertices.
-    :type delunused: bool, optional
+    :type dim: `int`, optional
+    :param delete_unused: flag to delete disjoint vertices.
+    :type delete_unused: `boolean`, optional
 
     :return: p: updated point coordinates of mesh
-    :rtype: numpy.ndarray[float64 x dim]
+    :rtype: numpy.ndarray[`float` x dim]
     :return: t: updated mesh connectivity
-    :rtype: numpy.ndarray[int x (dim+1)]
+    :rtype: numpy.ndarray[`int` x (dim+1)]
     """
 
     # duplicate vertices
@@ -371,29 +233,29 @@ def fixmesh(p, t, ptol=2e-13, dim=2, delunused=False):
     t = unique_rows(t)
 
     # delete disjoint vertices
-    if delunused:
+    if delete_unused:
         pix, _, jx = np.unique(t, return_index=True, return_inverse=True)
         t = np.reshape(jx, (t.shape))
         p = p[pix, :]
         pix = ix[pix]
 
     # entity orientation is CCW
-    flip = simpvol(p, t) < 0
+    flip = simp_vol(p, t) < 0
     t[flip, :2] = t[flip, 1::-1]
 
     return p, t, jx
 
 
-def simpqual(p, t):
+def simp_qual(p, t):
     """Simplex quality radius-to-edge ratio
 
     :param p: vertex coordinates of mesh
-    :type p: numpy.ndarray[float64 x dim]
+    :type p: numpy.ndarray[`float` x dim]
     :param t: mesh connectivity
-    :type t: numpy.ndarray[int x (dim + 1)]
+    :type t: numpy.ndarray[`int` x (dim + 1)]
 
     :return: signed mesh quality: signed mesh quality (1.0 is perfect)
-    :rtype: numpy.ndarray[float64 x 1]
+    :rtype: numpy.ndarray[`float` x 1]
 
     """
     assert p.ndim == 2 and t.ndim == 2 and p.shape[1] + 1 == t.shape[1]
@@ -413,12 +275,12 @@ def get_edges(entities, dim=2):
     """Get the undirected edges of mesh in no order (NB: are repeated)
 
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param dim: dimension of the mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
     :return: edges: the edges that make up the mesh
-    :rtype: numpy.ndarray[int x 2]
+    :rtype: numpy.ndarray[`int`x 2]
     """
 
     num_entities = len(entities)
@@ -436,12 +298,12 @@ def get_boundary_edges(entities, dim=2):
     """Get the boundary edges of the mesh. Boundary edges only appear (dim-1) times
 
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param dim: dimension of the mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
     :return: boundary_edges: the edges that make up the boundary of the mesh
-    :rtype: numpy.ndarray[int x 2]
+    :rtype: numpy.ndarray[`int` x 2]
     """
     edges = get_edges(entities, dim=dim)
     edges = np.sort(edges, axis=1)
@@ -454,10 +316,10 @@ def get_winded_boundary_edges(entities):
     """Order the boundary edges of the mesh in a winding fashiono
 
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
 
     :return: boundary_edges: the edges that make up the boundary of the mesh in a winding order
-    :rtype: numpy.ndarray[int x 2]
+    :rtype: numpy.ndarray[`int` x 2]
     """
 
     boundary_edges = get_boundary_edges(entities)
@@ -489,17 +351,19 @@ def get_boundary_vertices(entities, dim=2):
     """Get the indices of the mesh representing boundary vertices.
 
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int `x (dim+1)]
     :param dim: dimension of the mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
     :return: indices: indices into the vertex array that are on the boundary.
-    :rtype: numpy.ndarray[float64 x dim]
+    :rtype: numpy.ndarray[`float` x dim]
     """
     if dim == 2:
         b = get_boundary_edges(entities)
     elif dim == 3:
         b = get_boundary_facets(entities)
+    else:
+        raise ValueError("Dimension not supported.")
     indices = np.unique(b.reshape(-1))
     return indices
 
@@ -508,14 +372,14 @@ def get_boundary_entities(vertices, entities, dim=2):
     """Determine the entities that lie on the boundary of the mesh.
 
     :param vertices: vertex coordinates of mesh
-    :type vertices: numpy.ndarray[float64 x dim]
+    :type vertices: numpy.ndarray[`float` x dim]
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param dim: dimension of the mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
     :return: bele: indices of entities on the boundary of the mesh.
-    :rtype: numpy.ndarray[int x 1]
+    :rtype: numpy.ndarray[`int` x 1]
     """
     boundary_vertices = get_boundary_vertices(entities, dim=dim)
     vtoe, ptr = vertex_to_entities(vertices, entities, dim=dim)
@@ -531,10 +395,10 @@ def get_facets(entities):
     """Gets the four facets of each tetrahedral.
 
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
 
     :return: facets: facets of a tetrahedral entity.
-    :rtype: numpy.ndarray[int x 4]
+    :rtype: numpy.ndarray[`int` x 4]
     """
     ix = [[0, 1, 3], [1, 2, 3], [2, 0, 3], [1, 2, 0]]
     return np.array(entities[:, ix]).reshape((len(entities) * 4, 3))
@@ -544,11 +408,13 @@ def get_boundary_facets(entities):
     """Get the facets that represent the boundary of a 3D mesh.
 
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
 
     :return: boundary_facets: facets on the boundary of a 3D mesh.
-    :rtype: numpy.ndarray[int x 4]
+    :rtype: numpy.ndarray[`int` x 4]
     """
+    if entities.shape[1] < 4:
+        raise ValueError("Only works for triangles")
     facets = get_facets(entities)
     facets = np.sort(facets, axis=1)
     unq, cnt = np.unique(facets, axis=0, return_counts=True)
@@ -556,45 +422,40 @@ def get_boundary_facets(entities):
     return boundary_facets
 
 
-def delete_boundary_entities(vertices, entities, dim=2, minqual=0.10):
+def delete_boundary_entities(vertices, entities, dim=2, min_qual=0.10):
     """Delete boundary entities with poor geometric quality (i.e., < min. quality)
 
     :param vertices: vertex coordinates of mesh
-    :type vertices: numpy.ndarray[float64 x dim]
+    :type vertices: numpy.ndarray[`float` x dim]
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param dim: dimension of the mesh
-    :type dim: int, optional
-    :param minqual: minimum geometric quality to consider "poor" quality
-    :type minqual: float64, optional
+    :type dim: `int`, optional
+    :param min_qual: minimum geometric quality to consider "poor" quality
+    :type min_qual: `float`, optional
 
     :return: vertices: updated vertex array of mesh
-    :rtype: numpy.ndarray[int x dim]
+    :rtype: numpy.ndarray[`int` x dim]
     :return: entities: update mesh connectivity
-    :rtype: numpy.ndarray[int x (dim+1)]
+    :rtype: numpy.ndarray[`int` x (dim+1)]
     """
-    qual = simpqual(vertices, entities)
+    qual = simp_qual(vertices, entities)
     bele = get_boundary_entities(vertices, entities, dim=dim)
     qualBou = qual[bele]
-    delete = qualBou < minqual
+    delete = qualBou < min_qual
     print(
         "Deleting " + str(np.sum(delete)) + " poor quality boundary entities...",
         flush=True,
     )
     delete = np.argwhere(delete == 1)
     entities = np.delete(entities, bele[delete], axis=0)
-    vertices, entities, _ = fixmesh(vertices, entities, delunused=True, dim=dim)
+    vertices, entities, _ = fix_mesh(vertices, entities, delete_unused=True, dim=dim)
     return vertices, entities
 
 
 def _sparse(Ix, J, S, shape=None, dtype=None):
     """
     Similar to MATLAB's SPARSE(I, J, S, ...)
-
-    Usage
-    -----
-    >>> shape = (m, n)
-    >>> A = sparse(I, J, S, shape, dtype)
     """
 
     # Advanced usage: allow J and S to be scalars.
@@ -619,19 +480,22 @@ def laplacian2(vertices, entities, max_iter=20, tol=0.01):
     with the goal to hopefully improve geometric entity quality.
 
     :param vertices: vertex coordinates of mesh
-    :type vertices: numpy.ndarray[float64 x dim]
+    :type vertices: numpy.ndarray[`float` x dim]
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param max_iter: maximum number of iterations to perform
-    :type max_iter: int, optional
+    :type max_iter: `int`, optional
     :param tol: iterations will cease when movement < tol
-    :type tol: float64, optional
+    :type tol: `float`, optional
 
     :return vertices: updated vertices of mesh
-    :rtype: numpy.ndarray[float64 x dim]
+    :rtype: numpy.ndarray[`float` x dim]
     :return: entities: updated mesh connectivity
-    :rtype: numpy.ndarray[int x (dim+1)]
+    :rtype: numpy.ndarray[`int` x (dim+1)]
     """
+    if vertices.ndim != 2:
+        raise NotImplementedError("Laplacian smoothing is only works in 2D for now")
+
     eps = np.finfo(float).eps
 
     n = len(vertices)
@@ -675,21 +539,21 @@ def laplacian2(vertices, entities, max_iter=20, tol=0.01):
     return vertices, entities
 
 
-def isManifold(vertices, entities, dim=2):
+def is_manifold(vertices, entities, dim=2):
     """Determine if mesh is manifold by checking for the following:
     1. A boundary edge should be a member of one entity
     2. A non-boundary edge should be a member of two entities
     3. The number of boundary vertices == number of boundary edges
 
     :param vertices: vertex coordinates of mesh
-    :type vertices: numpy.ndarray[float64 x dim]
+    :type vertices: numpy.ndarray[`float` x dim]
     :param entities: the mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param dim: dimension of the mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
-    :return: isManifold: flag to indicate if the mesh has a manifold boundary.
-    :rtype: bool.
+    :return: is_manifold: flag to indicate if the mesh has a manifold boundary.
+    :rtype: `boolean`.
     """
     bedges = get_boundary_edges(entities, dim=dim)
     if bedges.size != vertices[np.unique(bedges), :].size:
@@ -698,17 +562,17 @@ def isManifold(vertices, entities, dim=2):
     return True
 
 
-def vtInEntity2(vertex, entity):
+def vertex_in_entity2(vertex, entity):
     """
     Does the 2D vertex lie in the entity defined by vertices (x1,y1,x2,y2,x3,y3)?
 
     :param vertex: vertex coordinates of mesh
-    :type vertex: numpy.ndarray[float64 x dim]
+    :type vertex: numpy.ndarray[`float` x dim]
     :param entity: connectivity of an entity
-    :type entity: numpy.ndarray[int x (dim+1)]
+    :type entity: numpy.ndarray[`int` x (dim+1)]
 
-    :return: vtInEntity2: logical flag indicating if it is or isn't.
-    :rtype: bool
+    :return: vertex_in_entity2: logical flag indicating if it is or isn't.
+    :rtype: `boolean`
     """
     (x, y) = vertex
     (x1, y1, x2, y2, x3, y3) = entity
@@ -723,17 +587,17 @@ def vtInEntity2(vertex, entity):
     return 0 <= a and a <= 1 and 0 <= b and b <= 1 and 0 <= c and c <= 1
 
 
-def vtInEntity3(vertex, entity):
+def vertex_in_entity3(vertex, entity):
     """
     Does the 3D vertex lie in the entity defined by vertices (x1,y1,z1,x2,y2,z2,x3,y3,z3)?
 
     :param vertex: vertex coordinates of mesh
-    :type vertex: numpy.ndarray[float64 x dim]
+    :type vertex: numpy.ndarray[`float` x dim]
     :param entity: connectivity of an entity
-    :type entity: numpy.ndarray[int x (dim+1)]
+    :type entity: numpy.ndarray[`int` x (dim+1)]
 
-    :return: vtInEntity3: logical flag indicating if it is or isn't.
-    :rtype: bool
+    :return: vertex_in_entity3: logical flag indicating if it is or isn't.
+    :rtype: `boolean`
     """
     (x, y, z) = vertex
     (x1, y1, z1, x2, y2, z2, x3, y3, z3, x4, y4, z4) = entity
@@ -774,30 +638,30 @@ def get_centroids(vertices, entities, dim=2):
     """Calculate the centroids of all the entities.
 
     :param vertex: vertex coordinates of mesh
-    :type vertex: numpy.ndarray[float64 x dim]
+    :type vertex: numpy.ndarray[`float` x dim]
     :param entities: mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param dim: dimension of mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
     :return: centroids of entities
-    :rtype: numpy.ndarray[float64 x dim]
+    :rtype: numpy.ndarray[`float` x dim]
     """
     return vertices[entities].sum(1) / (dim + 1)
 
 
-def doAnyOverlap(vertices, entities, dim=2):
+def do_any_overlap(vertices, entities, dim=2):
     """
     Check if any entities connected to boundary of the mesh overlap
     ignoring self-intersections. This routine checks only the 1-ring around
     each entity for potential intersections using barycentric coordinates.
 
     :param vertex: vertex coordinates of mesh
-    :type vertex: numpy.ndarray[float64 x dim]
+    :type vertex: numpy.ndarray[`float` x dim]
     :param entities: mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param dim: dimension of mesh
-    :type dim: int, optional
+    :type dim: `int`, optional
 
     :return: intersections: a list of 2-tuple of entity indices that intersect
     :rtype: List[tuple(num_intersections x 2)]
@@ -825,7 +689,7 @@ def doAnyOverlap(vertices, entities, dim=2):
                 # does this centroid live inside another neighboring face?
                 x1, x2, x3 = vertices[entities[ele, :], 0]
                 y1, y2, y3 = vertices[entities[ele, :], 1]
-                if vtInEntity2((cent[0], cent[1]), (x1, y1, x2, y2, x3, y3)):
+                if vertex_in_entity2((cent[0], cent[1]), (x1, y1, x2, y2, x3, y3)):
                     # centroid ie is inside face iee
                     print(
                         "Alert: entity "
@@ -842,7 +706,7 @@ def doAnyOverlap(vertices, entities, dim=2):
                 x1, x2, x3, x4 = vertices[entities[ele], 0]
                 y1, y2, y3, y4 = vertices[entities[ele], 1]
                 z1, z2, z3, z4 = vertices[entities[ele], 2]
-                if vtInEntity3(
+                if vertex_in_entity3(
                     (cent[0], cent[1], cent[2]),
                     (x1, y1, z1, x2, y2, z2, x3, y3, z3, x4, y4, z4),
                 ):
@@ -861,52 +725,48 @@ def doAnyOverlap(vertices, entities, dim=2):
     return intersections
 
 
-def linter(vertices, entities, dim=2, minqual=0.10):
+def linter(vertices, entities, dim=2, min_qual=0.10):
     """Remove and check mesh for geometric and toplogical defects.
 
     :param vertex: vertex coordinates of mesh
-    :type vertex: numpy.ndarray[float64 x dim]
+    :type vertex: numpy.ndarray[`float` x dim]
     :param entities: mesh connectivity
-    :type entities: numpy.ndarray[int x (dim+1)]
+    :type entities: numpy.ndarray[`int` x (dim+1)]
     :param dim: dimension of mesh
-    :type dim: int, optional
-    :param minqual: minimum geometric quality to consider "poor" quality
-    :type minqual: float64, optional
+    :type dim: `int`, optional
+    :param min_qual: minimum geometric quality to consider "poor" quality
+    :type min_qual: `float`, optional
 
     :return vertices: updated mesh vertices
-    :rtype: numpy.ndarray[float64 x dim]
+    :rtype: numpy.ndarray[`float` x dim]
     :return: entities: updated mesh connectivity
-    :rtype: numpy.ndarray[int x (dim+1)]
+    :rtype: numpy.ndarray[`int` x (dim+1)]
     """
     print("Performing mesh linting...", flush=True)
-    qual = simpqual(vertices, entities)
+    qual = simp_qual(vertices, entities)
     # determine if there's degenerate overlapping elements
-    # import time
-
-    # t1 = time.time()
-    # intersections = doAnyOverlap(vertices, entities, dim=dim)
+    intersections = do_any_overlap(vertices, entities, dim=dim)
     # delete the lower quality in the pair
-    # Delete = []
-    # For intersect in intersections:
-    #    ix = [i for i in intersect]
-    #    sel = np.argmin(qual[ix])
-    #    delete = np.append(delete, intersect[sel])
-    # Delete = np.unique(delete)
-    # Print("Deleting " + str(len(delete)) + " overlapped entities", flush=True)
-    # Entities = np.delete(entities, delete, axis=0)
-    # Print(time.time() - t1)
+    delete = np.array([], dtype=int)
+    for intersect in intersections:
+        ix = [i for i in intersect]
+        sel = np.argmin(qual[ix])
+        delete = np.append(delete, intersect[sel])
+    delete = np.unique(delete)
+    print("Deleting " + str(len(delete)) + " overlapped entities", flush=True)
+    entities = np.delete(entities, delete, axis=0)
 
     # clean up
-    vertices, entities, _ = fixmesh(vertices, entities, delunused=True)
+    vertices, entities, _ = fix_mesh(vertices, entities, delete_unused=True)
     # delete remaining low quality boundary elements
     if dim == 2:
         vertices, entities = delete_boundary_entities(
-            vertices, entities, minqual=minqual
+            vertices, entities, min_qual=min_qual
         )
         # check for non-manifold boundaries and alert
-        _ = isManifold(vertices, entities)
+        _ = is_manifold(vertices, entities)
     # calculate final minimum simplex quality
-    qual = simpqual(vertices, entities)
+    qual = simp_qual(vertices, entities)
     minimum_quality = np.amin(qual)
     print(
         "There are "
